@@ -13,13 +13,20 @@ def test_readme():
 
     m1 = MyModel(x=2, e="b")
     yml = m1.yaml()
+    jsn = m1.json()
 
-    m2 = MyModel.parse_raw(yml, proto="yaml")
+    m2 = MyModel.parse_raw(yml)  # This automatically assumes YAML
     assert m1 == m2
 
-    m3 = MyModel.parse_raw(yml, content_type="application/yaml")
+    m3 = MyModel.parse_raw(jsn)  # This will fallback to JSON
     assert m1 == m3
 
+    m4 = MyModel.parse_raw(yml, proto="yaml")
+    assert m1 == m4
+
+    m5 = MyModel.parse_raw(yml, content_type="application/yaml")
+    assert m1 == m5
+
 
 def test_nested_models():
     """Test nested YAML models"""
@@ -45,8 +52,5 @@ def test_nested_models():
     assert c == c_re
 
 
-# def test_recursive_yaml():
-#     """TODO: Test how we parse recursive YAML documents."""
-
 # def test_files():
 #     """TODO: Test with tempfiles."""
